@@ -34,6 +34,7 @@ from PyQt4.QtGui import *
 from PyQt4.QtNetwork import *
 
 import resources_rc
+import version
 import ui_btrw_main
 import ui_btrprogopts
 import ui_jobviewdlg
@@ -56,18 +57,19 @@ import ctimedlgs
 
 DIR_COLUMN = 0
 FILE_COLUMN = 1
-TITLE_COLUMN = 2
-CI_COLUMN = 3
-HAS_COLUMN = 4
-RUNC_COLUMN = 5
-SUBM_COLUMN = 6
-CH_COLUMN = 7
+QUEUE_COLUMN = 2
+TITLE_COLUMN = 3
+CI_COLUMN = 4
+HAS_COLUMN = 5
+RUNC_COLUMN = 6
+SUBM_COLUMN = 7
+CH_COLUMN = 8
 
-WIN = sys.platform == "win32"
-locale.setlocale(locale.LC_ALL, os.environ['LANG'])
+locale.setlocale(locale.LC_ALL, os.getenv('LANG', 'C'))
 
-if WIN:
+if btqwopts.WIN:
     import wininfo
+    import win32api
     filelocloc = "Software\\FSF\\GNUBatch\\serverdets"
     def savelocloc(fname):
         """Save location of current config file"""
@@ -301,7 +303,7 @@ Generally ignore errors"""
         return True
 
     def getprefserv(self):
-        """Get server structure for prefered host"""
+        """Get server structure for preferred host"""
         hostn = btqwopts.Options.btrwopts.prefhost
         if hostn is None or len(hostn) == 0:
             QMessageBox.warning(self, "No default host", "You need to have a default host set up to get permissions from")
@@ -311,7 +313,7 @@ Generally ignore errors"""
         except KeyError:
             QMessageBox.warning(self, "Unknown server", "The default server name of " + hostn + " is not known")
             return None
-        if serv.isok or btqwopts.Options.servlist.perform_login(self, serv):
+        if serv.isok or btqwopts.Options.servers.perform_login(self, serv):
             return serv
         QMessageBox.warning(self, "Cannot get permissions", "Cannot get permissions from default server " + hostn)
         return None
@@ -319,8 +321,10 @@ Generally ignore errors"""
     def getservperms(self):
         """Get perms structure for server"""
         if self.servperms is not None: return self.servperms
-        self.servperms = serv = self.getprefserv()
-        if serv is not None: return serv.perms
+        serv = self.getprefserv()
+        if serv is not None:
+            self.servperms = serv.perms
+            return serv.perms
         return None
 
     def listvars_perm(self, perm):
@@ -395,7 +399,9 @@ Generally ignore errors"""
         else:
             self.setup_stringbox(rownum, DIR_COLUMN, "")
             self.setup_stringbox(rownum, FILE_COLUMN, "")
-        self.setup_stringbox(rownum, TITLE_COLUMN, job.bj_title)
+        qname, tit = job.queue_title()
+        self.setup_stringbox(rownum, QUEUE_COLUMN, qname)
+        self.setup_stringbox(rownum, TITLE_COLUMN, tit)
         self.setup_stringbox(rownum, CI_COLUMN, job.bj_cmdinterp)
         st = "Run"
         if job.bj_progress == btclasses.btjob.BJP_CANCELLED: st = "Canc"
@@ -541,7 +547,7 @@ Generally ignore errors"""
                      continue
             bwo.verbose = dlg.verbose.isChecked()
             bwo.useexted = ue
-            bwo.inshell = sh
+            bwo.inshell = ish
             newh = str(dlg.defserver.currentText())
             if bwo.prefhost is None:
                 bwo.prefhost = newh
@@ -562,7 +568,7 @@ Generally ignore errors"""
             QMessageBox.warning(self, "No script", "Job does not currently have a script to view")
             return
         dlg = Cjobview(self)
-        dlg.jobdescr.setText("Job")
+        dlg.jobdescr.setText("Job " + cjob.bj_title + " c/i " + cjob.bj_cmdinterp)
         dlg.jobtext.appendPlainText(cjob.script)
         dlg.jobtext.moveCursor(QTextCursor.Start) # So find finds from beginning
         dlg.show()
@@ -594,7 +600,7 @@ Generally ignore errors"""
         else:
             # Use Qt dialog to edit it
             dlg = Cjobedit(self)
-            dlg.jobdescr.setText("Job")
+            dlg.jobdescr.setText("Job " + cjob.bj_title + " c/i " + cjob.bj_cmdinterp)
             if cjob.script is not None:
                 dlg.jobtext.appendPlainText(cjob.script)
             dlg.jobtext.moveCursor(QTextCursor.Start)
@@ -632,6 +638,12 @@ Generally ignore errors"""
             self.fillrow(cjob)
             self.updateUI()
 
+    def getqueues(self):
+        """Get a list of the current queues and ones we've ever encountered"""
+        qset = set(btqwopts.Options.btrwopts.qprefixes)
+        qset |= set([j.queueof() for j in self.jobs])
+        return qset
+
     def on_action_def_titprill_triggered(self, checked = None):
         if checked is None: return
         cjob = self.getdefaultjob()
@@ -644,10 +656,12 @@ Generally ignore errors"""
         dlg.init_cmdints(self.cilist, cjob.bj_cmdinterp, (perms.btu_priv & btuser.btuser.BTM_SPCREATE) != 0)
         dlg.init_pri(cjob.bj_pri, perms.btu_minp, perms.btu_maxp)
         dlg.edjob.setText("Defaults")
-        dlg.title.setText(cjob.bj_title)
+        qnam, tit = cjob.queue_title()
+        dlg.init_queues(self.getqueues(), qnam)
+        dlg.title.setText(tit)
         dlg.llev.setValue(cjob.bj_ll)
         if dlg.exec_():
-            cjob.bj_title = str(dlg.title.text())
+            cjob.set_title(str(dlg.queue.lineEdit().text()), str(dlg.title.text()))
             cjob.bj_pri = dlg.priority.value()
             cjob.bj_ll = dlg.llev.value()
             cjob.bj_cmdinterp = str(dlg.cmdint.currentText())
@@ -664,11 +678,13 @@ Generally ignore errors"""
         dlg.init_cmdints(self.cilist, cjob.bj_cmdinterp, (perms.btu_priv & btuser.btuser.BTM_SPCREATE) != 0)
         dlg.init_pri(cjob.bj_pri, perms.btu_minp, perms.btu_maxp)
         dlg.edjob.setText(cjob.jobname())
-        dlg.title.setText(cjob.bj_title)
+        qnam, tit = cjob.queue_title()
+        dlg.init_queues(self.getqueues(), qnam)
+        dlg.title.setText(tit)
         pri = cjob.bj_pri
         dlg.llev.setValue(cjob.bj_ll)
         if dlg.exec_():
-            cjob.bj_title = str(dlg.title.text())
+            cjob.set_title(str(dlg.queue.lineEdit().text()), str(dlg.title.text()))
             cjob.bj_pri = dlg.priority.value()
             cjob.bj_ll = dlg.llev.value()
             cjob.bj_cmdinterp = str(dlg.cmdint.currentText())
@@ -972,6 +988,8 @@ Generally ignore errors"""
             jobnum = jobsubmit.job_submit(serv, cjob)
         except jobsubmit.SubmError as err:
             QMessageBox.warning(self, "Submit problem", err.args[0])
+            serv.uasock.closeReopen()
+            serv.isok = False
             return
         if btqwopts.Options.btrwopts.verbose:
             QMessageBox.information(self, "Submission OK", "Job submitted OK, job number is " + str(jobnum))
@@ -1006,6 +1024,7 @@ Generally ignore errors"""
         if not self.oktoclose(): return
         btqwopts.Options.btrwopts.btrwgeom = self.geometry()
         btqwopts.Options.btrwopts.cwidths = self.get_cwidths()
+        btqwopts.Options.btrwopts.qprefixes = list(self.getqueues())
         btqwopts.save_options(self.get_recentfiles())
         QApplication.exit(0)
 
@@ -1020,9 +1039,9 @@ Generally ignore errors"""
     def on_action_About_BTRW_triggered(self, checked = None):
         if checked is None: return
         QMessageBox.about(self, "About BTRW",
-                                """<b>Btrw</b> v 1.7
+                                """<b>Btrw</b> v %s
                                 <p>Copyright &copy; %d Free Software Foundation
-                                <p>Python %s - Qt %s""" % (time.localtime().tm_year, platform.python_version(), QT_VERSION_STR))
+                                <p>Python %s - Qt %s""" % (version.VERSION, time.localtime().tm_year, platform.python_version(), QT_VERSION_STR))
 
 # We now save the files in the User's directory for Windows
 # or $HOME/.gbatch/ for UNIX
@@ -1030,7 +1049,7 @@ Generally ignore errors"""
 
 if btqwopts.WIN:
     floc = os.path.expanduser('~\\btqw.xbs')
-    winuser = wininfo.getwinuser()
+    winuser = win32api.GetUserName()
 else:
     # If we don't know who it is, then use HOME or if all else fails
     # the current directory
